@@ -76,7 +76,3 @@ fn test_from_str() {
     assert_eq!(DeviceId::new(8, 16), DeviceId::from_str("8:16").unwrap());
 }
 
-#[test]
-fn test_from_u64() {
-    assert_eq!(DeviceId::new(8, 16), DeviceId::from(2064u64));
-}
